@@ -2,20 +2,32 @@
  * @file ofdt.c
  *
  * Copyright (C) 2005 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author John Rose <johnrose@us.ibm.com>
  */
 
 #include <stdlib.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <string.h>
 #include <errno.h>
 #include <endian.h>
 #include <byteswap.h>
 #include "librtas.h"
-#include "common.h"
+#include "internal.h"
 
 static const char *ofdt_rtas_path = "/proc/device-tree/rtas";
 
@@ -63,12 +75,10 @@ static int open_prop_file(const char *prop_path, const char *prop_name, int *fd)
  * @param prop_len
  * @return 0 on success, !0 otherwise
  */
-static int
-get_property(const char *prop_path, const char *prop_name, char **prop_val,
-	     size_t * prop_len)
+static int get_property(const char *prop_path, const char *prop_name,
+			char **prop_val, size_t *prop_len)
 {
-	int fd;
-	int rc;
+	int rc, fd;
 
 	rc = open_prop_file(prop_path, prop_name, &fd);
 	if (rc)
@@ -94,8 +104,12 @@ int rtas_token(const char *call_name)
 	int rc;
 
 	rc = get_property(ofdt_rtas_path, call_name, &prop_buf, &len);
-	if (rc < 0) 
+	if (rc < 0) {
+		if (prop_buf)
+			free(prop_buf);
+
 		return RTAS_UNKNOWN_OP;
+	}
 
 #if __BYTE_ORDER == __LITTLE_ENDIAN
 	rc = bswap_32(*(int *)prop_buf);
@@ -139,10 +153,11 @@ int read_entire_file(int fd, char **buf, size_t * len)
 
 		rc = read(fd, *buf + off, BLOCK_SIZE);
 		if (rc < 0) {
-			dbg1("read failed\n");
+			dbg("read failed\n");
 			errno = EIO;
 			return -1;
 		}
+
 		off += rc;
 	} while (rc == BLOCK_SIZE);
 
