@@ -29,19 +29,9 @@
 #include <sys/syscall.h>
 #include <linux/unistd.h>
 #include <linux/types.h>
-#include "syscall.h"
+#include "internal.h"
 #include "librtas.h"
 
-/* The original librtas used the _syscall1 interface to get to the rtas
- * system call.  On recent versions of Linux though the _syscall1
- * interface was removed from unistd.h so we have moved to using the
- * syscall() interface instead.  The use of _syscall1 is left as the
- * default to avoid breaking the library on older systems.
- */
-#ifdef _syscall1
-_syscall1(int, rtas, void *, args);
-#endif
-
 #define CALL_AGAIN 1
 
 int dbg_lvl = 0;
@@ -103,7 +93,7 @@ static unsigned int handle_delay(int status, uint64_t * elapsed)
 	}
 	*elapsed += ms;
 
-	dbg("Return status %d, delaying for %ld ms\n", status, ms);
+	dbg("Return status %d, delaying for %lu ms\n", status, ms);
 	usleep(ms * 1000);
 	return 1;
 }
@@ -131,7 +121,7 @@ static void display_rtas_buf(struct rtas_args *args, int after)
 	 * values is enough for debugging purposes.
 	 */
 	if (!after) {
-		printf("RTAS call args.token = %d\n", be32toh(args->token));
+		printf("RTAS call args.token = %u\n", be32toh(args->token));
 		printf("RTAS call args.ninputs = %d\n", ninputs);
 		printf("RTAS call args.nret = %d\n", nret);
 		for (i = 0; i < ninputs; i++)
@@ -144,6 +134,26 @@ static void display_rtas_buf(struct rtas_args *args, int after)
 	}
 }
 
+#if defined(__powerpc__) || defined(__powerpc64__)
+/*
+ * When targeting any variant of powerpc we expect SYS_rtas to be
+ * defined.
+ */
+static int rtas_syscall(struct rtas_args *args)
+{
+	return syscall(SYS_rtas, args);
+}
+#else /* __powerpc__ || __powerpc64__ */
+/*
+ * For non-powerpc targets (which we allow for the sake of build
+ * coverage), always use an invalid syscall number.
+ */
+static int rtas_syscall(struct rtas_args *args)
+{
+	return syscall(-1, args);
+}
+#endif /* __powerpc__ || __powerpc64__ */
+
 /**
  * rtas_call
  * @brief Perform the actual  system call for the rtas call
@@ -177,11 +187,7 @@ static int _rtas_call(int delay_handling, int token, int ninputs,
 	display_rtas_buf(&args, 0);
 
 	do {
-#ifdef _syscall1
-		rc = rtas(&args);
-#else
-		rc = syscall(__NR_rtas, &args);
-#endif
+		rc = rtas_syscall(&args);
 		if (!delay_handling || (rc < 0))
 			break;
 
@@ -245,7 +251,7 @@ static int rtas_call(const char *name, int ninputs, int nrets, ...)
  *
  * @return 0 on success, !0 on failure
  */
-int rtas_activate_firmware()
+int rtas_activate_firmware(void)
 {
 	int rc, status;
 
@@ -282,11 +288,11 @@ int rtas_cfg_connector(char *workarea)
 	if (rc)
 		return rc;
 
-	rc = rtas_get_rmo_buffer(PAGE_SIZE, &kernbuf, &workarea_pa);
+	rc = rtas_get_rmo_buffer(WORK_AREA_SIZE, &kernbuf, &workarea_pa);
 	if (rc)
 		return rc;
 
-	memcpy(kernbuf, workarea, PAGE_SIZE);
+	memcpy(kernbuf, workarea, WORK_AREA_SIZE);
 
 	do {
 		rc = rtas_call_no_delay("ibm,configure-connector", 2, 1,
@@ -296,7 +302,7 @@ int rtas_cfg_connector(char *workarea)
 			break;
 
 		if ((rc == 0) && (status == CFG_RC_MEM)) {
-			rc = rtas_get_rmo_buffer(PAGE_SIZE, &extent,
+			rc = rtas_get_rmo_buffer(WORK_AREA_SIZE, &extent,
 						 &extent_pa);
 			if (rc < 0)
 				break;
@@ -308,12 +314,12 @@ int rtas_cfg_connector(char *workarea)
 	} while (rc == CALL_AGAIN);
 
 	if (rc == 0)
-		memcpy(workarea, kernbuf, PAGE_SIZE);
+		memcpy(workarea, kernbuf, WORK_AREA_SIZE);
 
-	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, PAGE_SIZE);
+	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, WORK_AREA_SIZE);
 
 	if (extent_pa)
-		(void)rtas_free_rmo_buffer(extent, extent_pa, PAGE_SIZE);
+		(void)rtas_free_rmo_buffer(extent, extent_pa, WORK_AREA_SIZE);
 
 	dbg("(%p) = %d\n", workarea, rc ? rc : status);
 	return rc ? rc : status;
@@ -513,7 +519,7 @@ int rtas_get_config_addr_info2(uint32_t config_addr, uint64_t phb_id,
 
 	*info = be32toh(be_info);
 
-	dbg("(0x%x, 0x%"PRIx64", %d) = %d, 0x%x\n", config_addr, phb_id, func,
+	dbg("(0x%x, 0x%"PRIx64", %u) = %d, 0x%x\n", config_addr, phb_id, func,
 	    rc ? rc : status, *info);
 	return rc ? rc : status;
 }
@@ -601,7 +607,7 @@ int rtas_get_indices(int is_sensor, int type, char *workarea, size_t size,
 
 	*next = be32toh(be_next);
 
-	dbg("(%d, %d, %p, %zd, %d, %p) = %d, %d\n", is_sensor, type, workarea,
+	dbg("(%d, %d, %p, %zu, %d, %p) = %d, %d\n", is_sensor, type, workarea,
 	     size, start, next, rc ? rc : status, *next);
 	return rc ? rc : status;
 }
@@ -701,7 +707,7 @@ int rtas_get_sysparm(unsigned int parameter, unsigned int length, char *data)
 
 	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, length);
 
-	dbg("(%d, %d, %p) = %d\n", parameter, length, data, rc ? rc : status);
+	dbg("(%u, %u, %p) = %d\n", parameter, length, data, rc ? rc : status);
 	return rc ? rc : status;
 }
 
@@ -741,7 +747,7 @@ int rtas_get_time(uint32_t *year, uint32_t *month, uint32_t *day,
 	*sec = be32toh(*sec);
 	*nsec = be32toh(*nsec);
 
-	dbg("() = %d, %d, %d, %d, %d, %d, %d, %d\n", rc ? rc : status, *year,
+	dbg("() = %d, %u, %u, %u, %u, %u, %u, %u\n", rc ? rc : status, *year,
 	    *month, *day, *hour, *min, *sec, *nsec);
 	return rc ? rc : status;
 }
@@ -775,17 +781,17 @@ int rtas_get_vpd(char *loc_code, char *workarea, size_t size,
 	if (rc)
 		return rc;
 
-	rc = rtas_get_rmo_buffer(size + PAGE_SIZE, &rmobuf, &rmo_pa);
+	rc = rtas_get_rmo_buffer(size + WORK_AREA_SIZE, &rmobuf, &rmo_pa);
 	if (rc)
 		return rc;
 
-	kernbuf = rmobuf + PAGE_SIZE;
-	kernbuf_pa = rmo_pa + PAGE_SIZE;
+	kernbuf = rmobuf + WORK_AREA_SIZE;
+	kernbuf_pa = rmo_pa + WORK_AREA_SIZE;
 	locbuf = rmobuf;
 	loc_pa = rmo_pa;
 
 	/* If user didn't set loc_code, copy a NULL string */
-	strncpy(locbuf, loc_code ? loc_code : "", PAGE_SIZE);
+	strncpy(locbuf, loc_code ? loc_code : "", WORK_AREA_SIZE);
 
 	*seq_next = htobe32(sequence);
 	do {
@@ -803,12 +809,12 @@ int rtas_get_vpd(char *loc_code, char *workarea, size_t size,
 	if (rc == 0)
 		memcpy(workarea, kernbuf, size);
 
-	(void) rtas_free_rmo_buffer(rmobuf, rmo_pa, size + PAGE_SIZE);
+	(void) rtas_free_rmo_buffer(rmobuf, rmo_pa, size + WORK_AREA_SIZE);
 
 	*seq_next = be32toh(*seq_next);
 	*bytes_ret = be32toh(*bytes_ret);
 
-	dbg("(%s, 0x%p, %zd, %d) = %d, %d, %d", loc_code ? loc_code : "NULL",
+	dbg("(%s, 0x%p, %zu, %u) = %d, %u, %u\n", loc_code ? loc_code : "NULL",
 	    workarea, size, sequence, status, *seq_next, *bytes_ret);
 	return rc ? rc : status;
 }
@@ -840,7 +846,7 @@ int rtas_lpar_perftools(int subfunc, char *workarea, unsigned int length,
 	if (rc)
 		return rc;
 
-	memcpy(kernbuf, workarea, PAGE_SIZE);
+	memcpy(kernbuf, workarea, WORK_AREA_SIZE);
 
 	*seq_next = htobe32(sequence);
 	do {
@@ -862,7 +868,7 @@ int rtas_lpar_perftools(int subfunc, char *workarea, unsigned int length,
 
 	*seq_next = be32toh(*seq_next);
 
-	dbg("(%d, %p, %d, %d, %p) = %d, %d\n", subfunc, workarea,
+	dbg("(%d, %p, %u, %u, %p) = %d, %u\n", subfunc, workarea,
 	    length, sequence, seq_next, rc ? rc : status, *seq_next);
 	return rc ? rc : status;
 }
@@ -935,7 +941,7 @@ int rtas_platform_dump(uint64_t dump_tag, uint64_t sequence, void *buffer,
 	bytes_lo = be32toh(bytes_lo);
 	*bytes_ret = BITS64(bytes_hi, bytes_lo);
 
-	dbg("(0x%"PRIx64", 0x%"PRIx64", %p, %zd, %p, %p) = %d, 0x%"PRIx64", 0x%"PRIx64"\n",
+	dbg("(0x%"PRIx64", 0x%"PRIx64", %p, %zu, %p, %p) = %d, 0x%"PRIx64", 0x%"PRIx64"\n",
 	     dump_tag, sequence, buffer, length, seq_next, bytes_ret,
 	     rc ? rc : status, *seq_next, *bytes_ret);
 	return rc ? rc : status;
@@ -1003,7 +1009,7 @@ int rtas_scan_log_dump(void *buffer, size_t length)
 
 	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, length);
 
-	dbg("(%p, %zd) = %d\n", buffer, length, rc ? rc : status);
+	dbg("(%p, %zu) = %d\n", buffer, length, rc ? rc : status);
 	return rc ? rc : status;
 }
 
@@ -1164,7 +1170,7 @@ int rtas_set_poweron_time(uint32_t year, uint32_t month, uint32_t day,
 		       htobe32(month), htobe32(day), htobe32(hour),
 		       htobe32(min), htobe32(sec), htobe32(nsec), &status);
 
-	dbg("(%d, %d, %d, %d, %d, %d, %d) = %d\n", year, month, day, hour,
+	dbg("(%u, %u, %u, %u, %u, %u, %u) = %d\n", year, month, day, hour,
 	    min, sec, nsec, rc ? rc : status);
 	return rc ? rc : status;
 }
@@ -1182,25 +1188,36 @@ int rtas_set_sysparm(unsigned int parameter, char *data)
 	uint32_t kernbuf_pa;
 	void *kernbuf;
 	int rc, status;
-	short size;
+	uint16_t size;
 
 	rc = sanity_check();
 	if (rc)
 		return rc;
-
-	size = *(short *)data;
-	rc = rtas_get_rmo_buffer(size + sizeof(short), &kernbuf, &kernbuf_pa);
+	/*
+	 * We have to copy the contents of @data to a RMO buffer. The
+	 * caller has encoded the data length in the first two bytes
+	 * of @data in MSB order, and we can't assume any
+	 * alignment. So interpret @data as:
+	 *
+	 * struct {
+	 *     unsigned char len_msb;
+	 *     unsigned char len_lsb;
+	 *     char [(len_msb << 8) + len_lsb];
+	 * }
+	 */
+	size = 2 + (((unsigned char)data[0] << 8) | (unsigned char)data[1]);
+	rc = rtas_get_rmo_buffer(size, &kernbuf, &kernbuf_pa);
 	if (rc)
 		return rc;
 
-	memcpy(kernbuf, data, size + sizeof(short));
+	memcpy(kernbuf, data, size);
 
 	rc = rtas_call("ibm,set-system-parameter", 2, 1, htobe32(parameter),
 		       htobe32(kernbuf_pa), &status);
 
-	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, size + sizeof(short));
+	(void)rtas_free_rmo_buffer(kernbuf, kernbuf_pa, size);
 
-	dbg("(%d, %p) = %d\n", parameter, data, rc ? rc : status);
+	dbg("(%u, %p) = %d\n", parameter, data, rc ? rc : status);
 	return rc ? rc : status;
 }
 
@@ -1230,7 +1247,7 @@ int rtas_set_time(uint32_t year, uint32_t month, uint32_t day, uint32_t hour,
 		       htobe32(day), htobe32(hour), htobe32(min),
 		       htobe32(sec), htobe32(nsec), &status);
 
-	dbg("(%d, %d, %d, %d, %d, %d, %d) = %d\n", year, month, day, hour,
+	dbg("(%u, %u, %u, %u, %u, %u, %u) = %d\n", year, month, day, hour,
 	    min, sec, nsec, rc ? rc : status);
 	return rc ? rc : status;
 }
@@ -1259,9 +1276,6 @@ int rtas_suspend_me(uint64_t streamid)
  * @param workarea input output work area for the rtas call
  * @param scope of call
  * @return 0 on success, !0 on failure
- *
- * Note that the PAPR defines the work area as 4096 bytes (as
- * opposed to a page), thus we use that rather than PAGE_SIZE below.
  */
 int rtas_update_nodes(char *workarea, unsigned int scope)
 {
@@ -1273,21 +1287,21 @@ int rtas_update_nodes(char *workarea, unsigned int scope)
 	if (rc)
 		return rc;
 
-	rc = rtas_get_rmo_buffer(4096, &kernbuf, &workarea_pa);
+	rc = rtas_get_rmo_buffer(WORK_AREA_SIZE, &kernbuf, &workarea_pa);
 	if (rc)
 		return rc;
 
-	memcpy(kernbuf, workarea, 4096);
+	memcpy(kernbuf, workarea, WORK_AREA_SIZE);
 
 	rc = rtas_call("ibm,update-nodes", 2, 1, htobe32(workarea_pa),
 		       htobe32(scope), &status);
 
 	if (rc == 0)
-		memcpy(workarea, kernbuf, 4096);
+		memcpy(workarea, kernbuf, WORK_AREA_SIZE);
 
-	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, PAGE_SIZE);
+	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, WORK_AREA_SIZE);
 
-	dbg("(%p) %d = %d\n", workarea, scope, rc ? rc : status);
+	dbg("(%p) %u = %d\n", workarea, scope, rc ? rc : status);
 	return rc ? rc : status;
 }
 
@@ -1298,9 +1312,6 @@ int rtas_update_nodes(char *workarea, unsigned int scope)
  * @param workarea input output work area for the rtas call
  * @param scope of call
  * @return 0 on success, !0 on failure
- *
- * Note that the PAPR defines the work area as 4096 bytes (as
- * opposed to a page), thus we use that rather than PAGE_SIZE below.
  */
 int rtas_update_properties(char *workarea, unsigned int scope)
 {
@@ -1312,21 +1323,21 @@ int rtas_update_properties(char *workarea, unsigned int scope)
 	if (rc)
 		return rc;
 
-	rc = rtas_get_rmo_buffer(4096, &kernbuf, &workarea_pa);
+	rc = rtas_get_rmo_buffer(WORK_AREA_SIZE, &kernbuf, &workarea_pa);
 	if (rc)
 		return rc;
 
-	memcpy(kernbuf, workarea, 4096);
+	memcpy(kernbuf, workarea, WORK_AREA_SIZE);
 
 	rc = rtas_call("ibm,update-properties", 2, 1, htobe32(workarea_pa),
 		       htobe32(scope), &status);
 
 	if (rc == 0)
-		memcpy(workarea, kernbuf, 4096);
+		memcpy(workarea, kernbuf, WORK_AREA_SIZE);
 
-	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, PAGE_SIZE);
+	(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, WORK_AREA_SIZE);
 
-	dbg("(%p) %d = %d\n", workarea, scope, rc ? rc : status);
+	dbg("(%p) %u = %d\n", workarea, scope, rc ? rc : status);
 	return rc ? rc : status;
 }
 
@@ -1346,7 +1357,7 @@ int rtas_physical_attestation(char *workarea, int seq_num, int *next_seq_num,
 	uint32_t workarea_pa;
 	uint64_t elapsed = 0;
 	void *kernbuf;
-	int kbuf_sz = 4096;
+	int kbuf_sz = WORK_AREA_SIZE;
 	int rc, status;
 	int resp_bytes = *work_area_bytes;
 
@@ -1378,7 +1389,7 @@ int rtas_physical_attestation(char *workarea, int seq_num, int *next_seq_num,
 	*next_seq_num = be32toh(*next_seq_num);
 
 	/* FW returned more data than we can handle */
-	if (be32toh(resp_bytes) > *work_area_bytes) {
+	if (be32toh(resp_bytes) > (unsigned int)*work_area_bytes) {
 		(void)rtas_free_rmo_buffer(kernbuf, workarea_pa, kbuf_sz);
 		return RTAS_IO_ASSERT;
 	}
