@@ -3,7 +3,20 @@
  * @brief generic routines to handle printing RTAS event sections
  *
  * Copyriht (C) 2005 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author Nathan Fontenot <nfont@austin.ibm.com>
  */
@@ -46,7 +59,7 @@ static FILE *ostream;
  * definitions for the rtas event sections from librtasevent.h.  Changes
  * need to be made in both places to avoid breaking librtasevent.
  */
-static int (*re_print_fns[])() = {
+static int (*re_print_fns[])(struct scn_header *shdr, int verbosity) = {
     NULL,
     print_re_hdr_scn,
     print_re_exthdr_scn,
@@ -117,8 +130,7 @@ static char *rtas_event_error_type[] = {
  * @param ... additional args a la printf()
  * @return number of characters printed
  */
-int
-print_scn_title(char *fmt, ...)
+int print_scn_title(char *fmt, ...)
 {
     va_list ap;
     int rspace;
@@ -141,7 +153,7 @@ print_scn_title(char *fmt, ...)
 
     offset += snprintf(buf + offset, sizeof(buf) - offset, "\n");
 
-    len = rtas_print(buf);
+    len = rtas_print("%s", buf);
     
     return len; 
 }
@@ -280,8 +292,7 @@ rtas_set_print_width(int width)
  * @param ... additional args a la printf()
  * @return number of bytes written
  */
-int
-rtas_print(char *fmt, ...)
+int rtas_print(char *fmt, ...)
 {
     va_list     ap;
     char        buf[1024];
@@ -330,7 +341,7 @@ rtas_print(char *fmt, ...)
 
             if (newline != NULL) {
                 prnt_len = newline - &tmpbuf[offset] + 1;
-                snprintf(buf + buf_offset, prnt_len, &tmpbuf[offset]);
+                snprintf(buf + buf_offset, prnt_len, "%s",&tmpbuf[offset]);
                 buf_offset = strlen(buf);
                 buf_offset += snprintf(buf + buf_offset,
 				       sizeof(buf) - buf_offset, "\n");
@@ -350,7 +361,7 @@ rtas_print(char *fmt, ...)
             }
 
             /* print up to the last brkpt */
-            snprintf(buf + buf_offset, prnt_len, &tmpbuf[offset]);
+            snprintf(buf + buf_offset, prnt_len, "%s", &tmpbuf[offset]);
             buf_offset = strlen(buf);
             buf_offset += snprintf(buf + buf_offset, sizeof(buf) - buf_offset,
 				   "\n");
@@ -361,10 +372,10 @@ rtas_print(char *fmt, ...)
     } 
 
     prnt_len = snprintf(buf + buf_offset, sizeof(buf) - buf_offset,
-			&tmpbuf[offset]);
+			"%s", &tmpbuf[offset]);
     line_offset += prnt_len;
 
-    return fprintf(ostream, buf);
+    return fprintf(ostream, "%s", buf);
 }
 
 /** 
