@@ -3,7 +3,20 @@
  * @brief RTAS event EPOW section routines
  *
  * Copyright (C) 2005 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author Nathan Fontenot <nfont@austin.ibm.com>
  * @author Jake Moilanen <moilanen@austin.ibm.com>
@@ -86,7 +99,7 @@ print_v4_epow(struct scn_header *shdr, int verbosity)
     int len = 0;
 
     len += print_scn_title("EPOW Warning");
-    len += rtas_print(PRNT_FMT_R, "EPOW Sensor Value:", epow->sensor_value); 
+    len += rtas_print(PRNT_FMT_R, "EPOW Sensor Value:", (uint32_t)epow->sensor_value); 
 
     if (version >= 3) {
         if (epow->sensor) {
@@ -95,7 +108,7 @@ print_v4_epow(struct scn_header *shdr, int verbosity)
                               "Sensor Token:", epow->sensor_token, 
                               "Sensor Index:", epow->sensor_index);
             len += rtas_print(PRNT_FMT_2,
-                              "Sensor Value:", epow->sensor_value,
+                              "Sensor Value:", (uint32_t)epow->sensor_value,
                               "Sensor Status:", epow->sensor_status);
         }
 
@@ -148,8 +161,8 @@ print_v6_epow(struct scn_header *shdr, int verbosity)
 
     len += print_v6_hdr("EPOW Warning", &epow->v6hdr, verbosity);
 
-    len += rtas_print(PRNT_FMT_2, "Sensor Value:", epow->sensor_value,
-                      "Action Code:", epow->action_code);
+    len += rtas_print(PRNT_FMT_2, "Sensor Value:", (uint32_t)epow->sensor_value,
+                      "Action Code:", (uint32_t)epow->action_code);
     len += rtas_print(PRNT_FMT_R, "EPOW Event:", epow->event_modifier);
 
     switch (epow->event_modifier) {
