@@ -2,13 +2,28 @@
  * @file rtas_event.h
  *
  * Copyright (C) 2005 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author Nathan Fontenot <nfont@austin.ibm.com>
  */
 
-#ifndef _H_RTAS_EVENT
-#define _H_RTAS_EVENT
+#ifndef RTAS_EVENT_H
+#define RTAS_EVENT_H
+
+#include <endian.h>
 
 #define PRNT_FMT        "%-20s%08x"
 #define PRNT_FMT_L      PRNT_FMT"    "
@@ -19,8 +34,8 @@
 void rtas_copy(void *, struct rtas_event *, uint32_t);
 
 /* parse routines */
-void parse_rtas_date(struct rtas_date *, struct rtas_date_raw *);
-void parse_rtas_time(struct rtas_time *, struct rtas_time_raw *);
+void parse_rtas_date(struct rtas_date *, struct rtas_date_raw);
+void parse_rtas_time(struct rtas_time *, struct rtas_time_raw);
 void parse_v6_hdr(struct rtas_v6_hdr *, struct rtas_v6_hdr_raw *);
 
 int parse_priv_hdr_scn(struct rtas_event *);
@@ -64,12 +79,14 @@ int print_re_hotplug_scn(struct scn_header *, int);
 
 int print_mtms(struct rtas_mtms *);
 
+__attribute__ ((format (printf, 1, 2)))
 int print_scn_title(char *, ...);
 int print_v6_hdr(char *, struct rtas_v6_hdr *, int);
 int print_raw_data(char *, int);
+__attribute__ ((format (printf, 1, 2)))
 int rtas_print(char *fmt, ...);
 struct scn_header * get_re_scn(struct rtas_event *, int);
 void add_re_scn(struct rtas_event *, void *, int);
 int re_scn_id(struct rtas_v6_hdr_raw *);
 
-#endif
+#endif /* RTAS_EVENT_H */
