@@ -3,7 +3,20 @@
  * @brief RTAS I/O event section routines
  *
  * Copyright (C) 2005 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author Nathan Fontenot <nfont@austin.ibm.com>
  * @author Jake Moilanen <moilanen@austin.ibm.com>
@@ -135,14 +148,14 @@ print_v4_io(struct scn_header *shdr, int verbosity)
     len += rtas_print("IOA Signaling the error: %x:%x.%x\n    vendor: %04x  "
 	              "device: %04x  rev: %02x  slot: %x\n", 
                       io->pci_sig_busno, io->pci_sig_devfn >> 3, 
-                      io->pci_sig_devfn & 0x7, io->pci_sig_vendorid, 
+                      io->pci_sig_devfn & 0x7U, io->pci_sig_vendorid, 
                       io->pci_sig_deviceid, io->pci_sig_revisionid, 
                       io->pci_sig_slot);
     
     len += rtas_print("IOA Sending during the error: %x:%x.%x\n"
                       "    vendor: %04x  device: %04x  rev: %02x  slot: %x\n", 
                       io->pci_send_busno, io->pci_send_devfn >> 3, 
-                      io->pci_send_devfn & 0x7, io->pci_send_vendorid, 
+                      io->pci_send_devfn & 0x7U, io->pci_send_vendorid, 
                       io->pci_send_deviceid, io->pci_send_revisionid, 
                       io->pci_send_slot);
    
