@@ -3,7 +3,20 @@
  * @brief Routines to print out various RTAS version 6 event sections
  *
  * Copyright (C) 2004 IBM Corporation
- * Common Public License Version 1.0 (see COPYRIGHT)
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * @author Nathan Fotenot <nfont@austin.ibm.com>
  */
@@ -27,19 +40,19 @@ static char *months[] = {"", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul",
                          "Dec"};
 
 void parse_rtas_date(struct rtas_date *rtas_date,
-		     struct rtas_date_raw *rawdate)
+		     struct rtas_date_raw rawdate)
 {
-    rtas_date->year = be16toh(rawdate->year);
-    rtas_date->month = rawdate->month;
-    rtas_date->day = rawdate->day;
+    rtas_date->year = be16toh(rawdate.year);
+    rtas_date->month = rawdate.month;
+    rtas_date->day = rawdate.day;
 }
 
-void parse_rtas_time(struct rtas_time *rtas_time, struct rtas_time_raw *rawtime)
+void parse_rtas_time(struct rtas_time *rtas_time, struct rtas_time_raw rawtime)
 {
-    rtas_time->hour = rawtime->hour;
-    rtas_time->minutes = rawtime->minutes;
-    rtas_time->seconds = rawtime->seconds;
-    rtas_time->hundredths = rawtime->hundredths;
+    rtas_time->hour = rawtime.hour;
+    rtas_time->minutes = rawtime.minutes;
+    rtas_time->seconds = rawtime.seconds;
+    rtas_time->hundredths = rawtime.hundredths;
 }
 
 void parse_v6_hdr(struct rtas_v6_hdr *v6hdr, struct rtas_v6_hdr_raw *rawv6)
@@ -67,7 +80,7 @@ print_v6_hdr(char *name, struct rtas_v6_hdr *v6hdr, int verbosity)
 {
     int len;
 
-    len = print_scn_title(name);
+    len = print_scn_title("%s", name);
 
     if (verbosity > 1) {
         len += rtas_print("%-20s      %c%c    "PRNT_FMT_R, 
@@ -103,8 +116,8 @@ parse_priv_hdr_scn(struct rtas_event *re)
 
     rawhdr = (struct rtas_priv_hdr_scn_raw *)(re->buffer + re->offset);
     parse_v6_hdr(&privhdr->v6hdr, &rawhdr->v6hdr);
-    parse_rtas_date(&privhdr->date, &rawhdr->date);
-    parse_rtas_time(&privhdr->time, &rawhdr->time);
+    parse_rtas_date(&privhdr->date, rawhdr->date);
+    parse_rtas_time(&privhdr->time, rawhdr->time);
 
     privhdr->creator_id = rawhdr->creator_id;
     privhdr->scn_count = rawhdr->scn_count;
@@ -373,7 +386,7 @@ print_usr_hdr_event_data(struct rtas_usr_hdr_scn *usrhdr)
                               "shutdown.\n");
             break;
         default:
-	    len += rtas_print("Unknown event type (%d).\n", usrhdr->event_type);
+	    len += rtas_print("Unknown event type (%u).\n", usrhdr->event_type);
             break;
     }
     
@@ -430,7 +443,7 @@ print_usr_hdr_event_data(struct rtas_usr_hdr_scn *usrhdr)
                               "produce incorrect results.\n");
             break;
 	default:
-	    len += rtas_print("Unknown event severity (%d).\n",
+	    len += rtas_print("Unknown event severity (%u).\n",
                               usrhdr->event_type);
             break;
     }
@@ -640,6 +653,7 @@ parse_generic_v6_scn(struct rtas_event *re)
         uint32_t    data_sz = gen->v6hdr.length - RTAS_V6_HDR_SIZE;
         gen->data = malloc(data_sz);
         if (gen->data == NULL) {
+	    free(gen);
             errno = ENOMEM;
             return -1;
         }
